Re: [PATCH 18/26] m68k: rename __iounmap and mark it static

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Hi Christoph,

On Sat, Aug 17, 2019 at 9:49 AM Christoph Hellwig <hch@xxxxxx> wrote:
m68k uses __iounmap as the name for an internal helper that is only
used for some CPU types.  Mark it static and give it a better name.

Signed-off-by: Christoph Hellwig <hch@xxxxxx>

Thanks for your patch!

--- a/arch/m68k/mm/kmap.c
+++ b/arch/m68k/mm/kmap.c
@@ -52,6 +52,7 @@ static inline void free_io_area(void *addr)

 #define IO_SIZE                (256*1024)

+static void __free_io_area(void *addr, unsigned long size);
 static struct vm_struct *iolist;

 static struct vm_struct *get_io_area(unsigned long size)
@@ -90,7 +91,7 @@ static inline void free_io_area(void *addr)
                if (tmp->addr == addr) {
                        *p = tmp->next;
                        /* remove gap added in get_io_area() */
-                       __iounmap(tmp->addr, tmp->size - IO_SIZE);
+                       __free_io_area(tmp->addr, tmp->size - IO_SIZE);
                        kfree(tmp);
                        return;
                }
@@ -249,12 +250,13 @@ void iounmap(void __iomem *addr)
 }
 EXPORT_SYMBOL(iounmap);

+#ifndef CPU_M68040_OR_M68060_ONLY

Cant you move this block up, to avoid adding more #ifdef cluttery?
The rest looks good to me.

 /*
  * __iounmap unmaps nearly everything, so be careful
  * Currently it doesn't free pointer/page tables anymore but this
  * wasn't used anyway and might be added later.
  */
-void __iounmap(void *addr, unsigned long size)
+static void __free_io_area(void *addr, unsigned long size)
 {
        unsigned long virtaddr = (unsigned long)addr;
        pgd_t *pgd_dir;
@@ -297,6 +299,7 @@ void __iounmap(void *addr, unsigned long size)

        flush_tlb_all();
 }
+#endif /* CPU_M68040_OR_M68060_ONLY */

 /*
  * Set new cache mode for some kernel address space.
@@ -249,12 +250,13 @@ void iounmap(void __iomem *addr)

 /*
- * __iounmap unmaps nearly everything, so be careful
+ * __free_io_area unmaps nearly everything, so be careful
  * Currently it doesn't free pointer/page tables anymore but this
  * wasn't used anyway and might be added later.

Gr{oetje,eeting}s,

                        Geert

-- 
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@xxxxxxxxxxxxxx

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds



[Index of Archives]     [Video for Linux]     [Yosemite News]     [Linux S/390]     [Linux Kernel]     [Linux SCSI]

  Powered by Linux